import pandas as pd
import tldextract
import requests
import re
from bs4 import BeautifulSoup


def get_homepage_text(domain: str) -> str:
    HEADERS = {
        "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/14.0 Safari/605.1.15",
        "Accept": "text/html",
        "Referer": "https://www.google.com",
    }
    try:
        resp = requests.get(f"http://www.{domain}", headers=HEADERS)
    except:
        print(f"failed on www.{domain}\ntrying without www")
        resp = requests.get(f"http://{domain}", headers=HEADERS)

    soup = BeautifulSoup(resp.text, "html.parser")
    homepage_text = soup.text.strip()
    homepage_text = re.sub(r"\s+", " ", homepage_text)
    print(homepage_text)
    return homepage_text

def clean_columns(df: pd.DataFrame) -> pd.DataFrame:
    df.columns = [col.lower().replace(" ", "_").replace(".", "") for col in df.columns]
    return df


def clean_domain(url: str) -> str:
    if url:
        ext = tldextract.extract(url.strip())  # handled uk.co, and high stars
        return ext.registered_domain
    return None


def domain_is_none(url: str) -> bool:
    return url is None or url == ""



import googlemaps
import pandas as pd
from googleapiclient.discovery import build

import gandai as ts
from gandai import secrets

gmaps = googlemaps.Client(key=secrets.access_secret_version("GOOLE_MAPS_KEY"))


def search(q: str, count: int = 10) -> pd.DataFrame:
    if count > 100:
        print("max @ 100 for now")
        count = 100

    all_results = []
    for i in range(0, count, 10):
        service = build(
            "customsearch",
            "v1",
            developerKey=secrets.access_secret_version("GOOGLE_SEARCH_KEY"),
        )
        results = service.cse().list(q=q, cx="12cb7a511cc804eb0", start=i).execute()
        all_results.extend(results["items"])
    df = pd.DataFrame(all_results)[["title", "link", "snippet"]]
    return df


def get_google_places(q: str) -> pd.DataFrame:
    results = []
    resp = gmaps.places(
        query=q,
    )
    results.extend(resp["results"])
    results = pd.DataFrame(results)[
        ["name", "place_id", "rating", "user_ratings_total"]
    ]
    return results
